Builder

Struct Builder 

pub struct Builder<B>
where B: RwBuilder,
{ /* private fields */ }
Available on crate feature postcard only.
Type returned by the postcard function on the RwBuilderExt trait. It acts as a sink/source for serde operations using postcard binary format.

Implementations

Source

impl<B> Builder<B>
where B: RwBuilder,

pub const fn new(builder: B) -> Self

Factory function to wrap an inner builder

Source

impl<B> Builder<B>
where B: RwBuilder, B::Reader: Read, B::Writer: Write,

pub fn load<T: DeserializeOwned>(&self) -> Result<T>

Load an item by executing the configured reader chain and decoding via Postcard

Errors

Returns an error if the underlying reader fails or if the deserialization fails.

pub fn save<T: Serialize>(&self, item: &T) -> Result<()>

Save an item by executing the configured writer chain and encoding via Postcard

Errors

Returns an error if the underlying writer fails or if the serialization fails.