pub struct CrcBuilder<B>where
B: RwBuilder,{ /* private fields */ }Available on crate feature
flate2 only.Expand description
Type returned by the crc function on the RwBuilder trait.
It is itself an RwBuilder so can be chained further, although this is an
uncommon scenario
Implementations