pub struct ProcessBuilder { /* private fields */ }Expand description
Type for building readers and writers on top of a process handle.
It is itself an RwBuilder, but can’t be created through one.
This is why we call it a source.
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn new(command: Command) -> Self
pub fn new(command: Command) -> Self
Create a builder that spawns a process based on the command being passed.
Sourcepub fn spawn(&self) -> Result<ChildBuilder>
pub fn spawn(&self) -> Result<ChildBuilder>
Spawn a child process based on the command and return the actual builder of the reader and writer. # Errors In case spawning the child process fails the reason why is return as an error.
Errors
Propagates the error of failing to spawn a child process