WincodeBuilder

Struct WincodeBuilder 

pub struct WincodeBuilder<B>
where B: RwBuilder,
{ /* private fields */ }
Available on crate feature wincode only.
Type returned by the wincode function on the RwBuilder trait. It is itself not an RwBuilder so can’t be chained further. This is why we call it a sink.

Note: This builder provides load and save methods for serialization. Due to wincode’s schema trait requirements, types must implement both serde traits and wincode’s SchemaRead/SchemaWrite traits.

Implementations

Source

impl<B> Builder<B>
where B: RwBuilder,

pub const fn new(builder: B) -> Self

Factory function to wrap an inner builder

pub fn load<T>(&self) -> Result<T>
where T: for<'de> Deserialize<'de> + for<'de> SchemaRead<'de, DefaultConfig, Dst = T>,

Load a value from the builder

Errors

Returns an error if deserialization or reading fails

pub fn save<T>(&self, value: &T) -> Result<()>
where T: Serialize + SchemaWrite<DefaultConfig, Src = T> + ?Sized,

Save a value to the builder

Errors

Returns an error if serialization or writing fails