AdhocWriter

Trait AdhocWriter 

pub trait AdhocWriter {
    // Required method
    fn write_string(&self, text: &str) -> Result<()>;
}
Creates a writer and writes the string to it

Required Methods

fn write_string(&self, text: &str) -> Result<()>

Write a string to a built writer

Errors

If either the writer creation or the write operation fails the error is propagated.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors