RwBuilderExt

Trait RwBuilderExt 

pub trait RwBuilderExt: RwBuilder {
Show 24 methods // Provided methods fn buffered(self) -> BufferedBuilder<Self> { ... } fn string(self) -> Builder<Self> { ... } fn wincode(self) -> WincodeBuilder<Self> { ... } fn chacha20( self, key: ChaCha20Key, nonce: ChaCha20Nonce, ) -> ChaCha20Builder<Self> { ... } fn salsa20( self, key: Salsa20Key, nonce: Salsa20Nonce, ) -> Salsa20Builder<Self> { ... } fn crc(self) -> CrcBuilder<Self> { ... } fn deflate( self, compression: Compression, ) -> CompressionBuilder<Self, Deflate> { ... } fn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz> { ... } fn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib> { ... } fn zstd(self, level: i32) -> ZstdBuilder<Self> { ... } fn bzip2(self, compression: BzCompression) -> BzBuilder<Self> { ... } fn lz4_flex(self) -> Lz4Builder<Self> { ... } fn hash<D: Digest>(self) -> DigestBuilder<Self, D> { ... } fn sha256(self) -> Sha256Builder<Self> { ... } fn sha512(self) -> Sha512Builder<Self> { ... } fn sha3_256(self) -> Sha3_256Builder<Self> { ... } fn sha3_512(self) -> Sha3_512Builder<Self> { ... } fn crc32fast(self) -> Crc32FastBuilder<Self> { ... } fn rmp_serde(self) -> Builder<Self> { ... } fn base64(self) -> Base64Builder<Self> { ... } fn serde_json(self) -> Builder<Self> { ... } fn postcard(self) -> Builder<Self> { ... } fn aes128_ctr( self, key: Aes128Key, nonce: AesNonce, ) -> Aes128CtrBuilder<Self> { ... } fn aes256_ctr( self, key: Aes256Key, nonce: AesNonce, ) -> Aes256CtrBuilder<Self> { ... }
}
Extension trait providing combinator methods for RwBuilder instances

Provided Methods

fn buffered(self) -> BufferedBuilder<Self>

Buffers the underlying readers and writers by wrapping them in a BufReader or BufWriter

fn string(self) -> Builder<Self>

Sink that provides a bridge between String instances and underlying readers and writers.

fn wincode(self) -> WincodeBuilder<Self>

Available on crate feature wincode only.

Sink that provides a bridge between serde and the underlying readers and writer by transforming from and to wincode.

fn chacha20( self, key: ChaCha20Key, nonce: ChaCha20Nonce, ) -> ChaCha20Builder<Self>

Available on crate feature chacha20 only.

Transformation that decrypts while reading and encrypts while writing using the chacha20 cipher

fn salsa20(self, key: Salsa20Key, nonce: Salsa20Nonce) -> Salsa20Builder<Self>

Available on crate feature salsa20 only.

Transformation that decrypts while reading and encrypts while writing using the salsa20 cipher

fn crc(self) -> CrcBuilder<Self>

Available on crate feature flate2 only.

Non-commutative transformation that hashes using the CRC algorithm

fn deflate(self, compression: Compression) -> CompressionBuilder<Self, Deflate>

Available on crate feature flate2 only.

Transformation that decompresses while reading and compresses while writing using the Deflate algorithm

fn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz>

Available on crate feature flate2 only.

Transformation that decompresses while reading and compresses while writing using the Gz algorithm

fn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib>

Available on crate feature flate2 only.

Transformation that decompresses while reading and compresses while writing using the Zlib algorithm

fn zstd(self, level: i32) -> ZstdBuilder<Self>

Available on crate feature zstd only.

Transformation that decompresses while reading and compresses while writing using the Zstd algorithm

fn bzip2(self, compression: BzCompression) -> BzBuilder<Self>

Available on crate feature bzip2 only.

Transformation that decompresses while reading and compresses while writing using the bzip2 algorithm

fn lz4_flex(self) -> Lz4Builder<Self>

Available on crate feature lz4_flex only.

Transformation that decompresses while reading and compresses while writing using the lz4_flex algorithm

fn hash<D: Digest>(self) -> DigestBuilder<Self, D>

Available on crate feature digest only.

Computes a hash or checksum using the digest crate’s Digest trait while reading and writing.

fn sha256(self) -> Sha256Builder<Self>

Available on crate feature sha2 only.

Computes a SHA256 hash while reading and writing.

fn sha512(self) -> Sha512Builder<Self>

Available on crate feature sha2 only.

Computes a SHA512 hash while reading and writing.

fn sha3_256(self) -> Sha3_256Builder<Self>

Available on crate feature sha3 only.

Computes a SHA3-256 hash while reading and writing.

fn sha3_512(self) -> Sha3_512Builder<Self>

Available on crate feature sha3 only.

Computes a SHA3-512 hash while reading and writing.

fn crc32fast(self) -> Crc32FastBuilder<Self>

Available on crate feature crc32fast only.

Computes a CRC32 checksum using the crc32fast crate while reading and writing.

fn rmp_serde(self) -> Builder<Self>

Available on crate feature rmp_serde only.

Sink that loads and saves values using rmp-serde (MessagePack).

fn base64(self) -> Base64Builder<Self>

Available on crate feature base64 only.

Transformation that encodes/decodes in base64 format.

fn serde_json(self) -> Builder<Self>

Available on crate feature serde_json only.

Sink that loads and saves values using serde_json (JSON).

fn postcard(self) -> Builder<Self>

Available on crate feature postcard only.

Sink that loads and saves values using postcard (Binary format).

fn aes128_ctr(self, key: Aes128Key, nonce: AesNonce) -> Aes128CtrBuilder<Self>

Available on crate feature aes_ctr only.

Transformation that decrypts while reading and encrypts while writing using the AES-128-CTR algorithm

fn aes256_ctr(self, key: Aes256Key, nonce: AesNonce) -> Aes256CtrBuilder<Self>

Available on crate feature aes_ctr only.

Transformation that decrypts while reading and encrypts while writing using the AES-256-CTR algorithm

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors