Crate rw_builder

Crate rw_builder 

rw-builder provides a convenient way to build std::io::Readers and std::io::Writers by chaining transformations. Since readers and writers are defined simultaneously through the same builder they can be used as inverses of each other.

Re-exports

pub use error::Error;
pub use error::Result;

Modules

error
Provides the error types used by the library.
rmp_serde
Provides the Builder for rmp-serde (MessagePack serialization/deserialization).

Structs

BufferedBuilder
Type returned by the buffered function on the RwBuilder trait. It is itself an RwBuilder so can be chained further.
BzBuilder
Type returned by the bzip2 function on the RwBuilderExt trait. It is itself an RwBuilder so can be chained further.
BzCompression
When compressing data, the compression level can be specified by a value in this enum.
Compression
When compressing data, the compression level can be specified by a value in this struct.
CompressionBuilder
Type returned by the deflate, gz and zlib functions on the RwBuilder trait. It is itself an RwBuilder so can be chained further.
Crc32FastBuilder
A builder that computes a CRC32 checksum using crc32fast
Crc32FastReader
A reader wrapper that computes a CRC32 checksum
Crc32FastWriter
A writer wrapper that computes a CRC32 checksum
CrcBuilder
Type returned by the crc function on the RwBuilder trait. It is itself an RwBuilder so can be chained further, although this is an uncommon scenario
DigestBuilder
A builder that computes a cryptographic hash or checksum on the stream.
DigestReader
A reader wrapper that computes a digest while reading.
DigestWriter
A writer wrapper that computes a digest while writing.
FileBuilder
Type for building readers and writers on top of a file handle. It is itself an RwBuilder, but can’t be created through one. This is why we call it a source.
Lz4Builder
Type returned by the lz4_flex function on the RwBuilderExt trait. It is itself an RwBuilder so can be chained further.
ProcessBuilder
Type for building readers and writers on top of a process handle. It is itself an RwBuilder, but can’t be created through one. This is why we call it a source.
TcpStreamBuilder
Type for building readers and writers on top of a connected TCP socket. It is itself an RwBuilder, but can’t be created through one. This is why we call it a source.
VecBuilder
Type for building readers and writers on top of a Vec in memory. It is itself an RwBuilder, but can’t be created through one. This is why we call it a source.
WincodeBuilder
Type returned by the wincode function on the RwBuilder trait. It is itself not an RwBuilder so can’t be chained further. This is why we call it a sink.
ZstdBuilder
Type returned by the zstd function on the RwBuilderExt trait. It is itself an RwBuilder so can be chained further.

Traits

AdhocWriter
Creates a writer and writes the string to it
Constructor
Convenience trait for creating a new encoder/decoder builder
RwBuilder
The trait that can construct readers and writers, but also has chainable functions to create more complex builders
RwBuilderExt
Extension trait providing combinator methods for RwBuilder instances
SerDe
Trait to wrap serialization and deserialization functionality behind uniform load and save functions

Type Aliases

Aes128Ctr
Internal type for AES-128-CTR cipher
Aes128CtrBuilder
The type returned by the aes128_ctr function in the RwBuilder trait
Aes128Key
The key type for the AES-128-CTR cipher
Aes256Ctr
Internal type for AES-256-CTR cipher
Aes256CtrBuilder
The type returned by the aes256_ctr function in the RwBuilder trait
Aes256Key
The key type for the AES-256-CTR cipher
AesNonce
The nonce type for AES-CTR cipher
ChaCha20Builder
The type returned by the chacha20 function in the RwBuilder trait
ChaCha20Key
The key type for the chacha20 cipher
ChaCha20Nonce
The nonce type for the chacha20 cipher (12 bytes for IETF variant)
Salsa20Builder
The type returned by the salsa20 function in the RwBuilder trait
Salsa20Key
The key type for the salsa20 cipher
Salsa20Nonce
The nonce type for the salsa20 cipher
Sha3_256Builder
The type returned by the sha3_256 function in the RwBuilder trait
Sha3_512Builder
The type returned by the sha3_512 function in the RwBuilder trait
Sha256Builder
The type returned by the sha256 function in the RwBuilder trait
Sha512Builder
The type returned by the sha512 function in the RwBuilder trait