pub struct WincodeBuilder<B>where
B: RwBuilder,{ /* private fields */ }Available on crate feature
wincode only.Expand description
Type returned by the wincode function on the RwBuilder trait.
It is itself not an RwBuilder so can’t be chained further.
This is why we call it a sink.
Note: This builder provides load and save methods for serialization.
Due to wincode’s schema trait requirements, types must implement both
serde traits and wincode’s SchemaRead/SchemaWrite traits.
Implementations