pub trait RwBuilderExt: RwBuilder {
Show 24 methods
// Provided methods
fn buffered(self) -> BufferedBuilder<Self> { ... }
fn string(self) -> Builder<Self> { ... }
fn wincode(self) -> WincodeBuilder<Self> { ... }
fn chacha20(
self,
key: ChaCha20Key,
nonce: ChaCha20Nonce,
) -> ChaCha20Builder<Self> { ... }
fn salsa20(
self,
key: Salsa20Key,
nonce: Salsa20Nonce,
) -> Salsa20Builder<Self> { ... }
fn crc(self) -> CrcBuilder<Self> { ... }
fn deflate(
self,
compression: Compression,
) -> CompressionBuilder<Self, Deflate> { ... }
fn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz> { ... }
fn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib> { ... }
fn zstd(self, level: i32) -> ZstdBuilder<Self> { ... }
fn bzip2(self, compression: BzCompression) -> BzBuilder<Self> { ... }
fn lz4_flex(self) -> Lz4Builder<Self> { ... }
fn hash<D: Digest>(self) -> DigestBuilder<Self, D> { ... }
fn sha256(self) -> Sha256Builder<Self> { ... }
fn sha512(self) -> Sha512Builder<Self> { ... }
fn sha3_256(self) -> Sha3_256Builder<Self> { ... }
fn sha3_512(self) -> Sha3_512Builder<Self> { ... }
fn crc32fast(self) -> Crc32FastBuilder<Self> { ... }
fn rmp_serde(self) -> Builder<Self> { ... }
fn base64(self) -> Base64Builder<Self> { ... }
fn serde_json(self) -> Builder<Self> { ... }
fn postcard(self) -> Builder<Self> { ... }
fn aes128_ctr(
self,
key: Aes128Key,
nonce: AesNonce,
) -> Aes128CtrBuilder<Self> { ... }
fn aes256_ctr(
self,
key: Aes256Key,
nonce: AesNonce,
) -> Aes256CtrBuilder<Self> { ... }
}Expand description
Extension trait providing combinator methods for RwBuilder instances
Provided Methods
Sourcefn buffered(self) -> BufferedBuilder<Self>
fn buffered(self) -> BufferedBuilder<Self>
Buffers the underlying readers and writers by wrapping them in a
BufReader or BufWriter
Sourcefn string(self) -> Builder<Self>
fn string(self) -> Builder<Self>
Sink that provides a bridge between String instances and underlying
readers and writers.
Sourcefn wincode(self) -> WincodeBuilder<Self>
Available on crate feature wincode only.
fn wincode(self) -> WincodeBuilder<Self>
wincode only.Sink that provides a bridge between serde and the underlying readers and writer by transforming from and to wincode.
Sourcefn chacha20(
self,
key: ChaCha20Key,
nonce: ChaCha20Nonce,
) -> ChaCha20Builder<Self>
Available on crate feature chacha20 only.
fn chacha20( self, key: ChaCha20Key, nonce: ChaCha20Nonce, ) -> ChaCha20Builder<Self>
chacha20 only.Transformation that decrypts while reading and encrypts while writing using the chacha20 cipher
Sourcefn salsa20(self, key: Salsa20Key, nonce: Salsa20Nonce) -> Salsa20Builder<Self>
Available on crate feature salsa20 only.
fn salsa20(self, key: Salsa20Key, nonce: Salsa20Nonce) -> Salsa20Builder<Self>
salsa20 only.Transformation that decrypts while reading and encrypts while writing using the salsa20 cipher
Sourcefn crc(self) -> CrcBuilder<Self>
Available on crate feature flate2 only.
fn crc(self) -> CrcBuilder<Self>
flate2 only.Non-commutative transformation that hashes using the CRC algorithm
Sourcefn deflate(self, compression: Compression) -> CompressionBuilder<Self, Deflate>
Available on crate feature flate2 only.
fn deflate(self, compression: Compression) -> CompressionBuilder<Self, Deflate>
flate2 only.Transformation that decompresses while reading and compresses while writing using the Deflate algorithm
Sourcefn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz>
Available on crate feature flate2 only.
fn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz>
flate2 only.Transformation that decompresses while reading and compresses while writing using the Gz algorithm
Sourcefn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib>
Available on crate feature flate2 only.
fn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib>
flate2 only.Transformation that decompresses while reading and compresses while writing using the Zlib algorithm
Sourcefn zstd(self, level: i32) -> ZstdBuilder<Self>
Available on crate feature zstd only.
fn zstd(self, level: i32) -> ZstdBuilder<Self>
zstd only.Transformation that decompresses while reading and compresses while writing using the Zstd algorithm
Sourcefn bzip2(self, compression: BzCompression) -> BzBuilder<Self>
Available on crate feature bzip2 only.
fn bzip2(self, compression: BzCompression) -> BzBuilder<Self>
bzip2 only.Transformation that decompresses while reading and compresses while writing using the bzip2 algorithm
Sourcefn lz4_flex(self) -> Lz4Builder<Self>
Available on crate feature lz4_flex only.
fn lz4_flex(self) -> Lz4Builder<Self>
lz4_flex only.Transformation that decompresses while reading and compresses while
writing using the lz4_flex algorithm
Sourcefn hash<D: Digest>(self) -> DigestBuilder<Self, D>
Available on crate feature digest only.
fn hash<D: Digest>(self) -> DigestBuilder<Self, D>
digest only.Computes a hash or checksum using the digest crate’s Digest trait while reading and writing.
Sourcefn sha256(self) -> Sha256Builder<Self>
Available on crate feature sha2 only.
fn sha256(self) -> Sha256Builder<Self>
sha2 only.Computes a SHA256 hash while reading and writing.
Sourcefn sha512(self) -> Sha512Builder<Self>
Available on crate feature sha2 only.
fn sha512(self) -> Sha512Builder<Self>
sha2 only.Computes a SHA512 hash while reading and writing.
Sourcefn sha3_256(self) -> Sha3_256Builder<Self>
Available on crate feature sha3 only.
fn sha3_256(self) -> Sha3_256Builder<Self>
sha3 only.Computes a SHA3-256 hash while reading and writing.
Sourcefn sha3_512(self) -> Sha3_512Builder<Self>
Available on crate feature sha3 only.
fn sha3_512(self) -> Sha3_512Builder<Self>
sha3 only.Computes a SHA3-512 hash while reading and writing.
Sourcefn crc32fast(self) -> Crc32FastBuilder<Self>
Available on crate feature crc32fast only.
fn crc32fast(self) -> Crc32FastBuilder<Self>
crc32fast only.Computes a CRC32 checksum using the crc32fast crate while reading and writing.
Sourcefn rmp_serde(self) -> Builder<Self>
Available on crate feature rmp_serde only.
fn rmp_serde(self) -> Builder<Self>
rmp_serde only.Sink that loads and saves values using rmp-serde (MessagePack).
Sourcefn base64(self) -> Base64Builder<Self>
Available on crate feature base64 only.
fn base64(self) -> Base64Builder<Self>
base64 only.Transformation that encodes/decodes in base64 format.
Sourcefn serde_json(self) -> Builder<Self>
Available on crate feature serde_json only.
fn serde_json(self) -> Builder<Self>
serde_json only.Sink that loads and saves values using serde_json (JSON).
Sourcefn postcard(self) -> Builder<Self>
Available on crate feature postcard only.
fn postcard(self) -> Builder<Self>
postcard only.Sink that loads and saves values using postcard (Binary format).
Sourcefn aes128_ctr(self, key: Aes128Key, nonce: AesNonce) -> Aes128CtrBuilder<Self>
Available on crate feature aes_ctr only.
fn aes128_ctr(self, key: Aes128Key, nonce: AesNonce) -> Aes128CtrBuilder<Self>
aes_ctr only.Transformation that decrypts while reading and encrypts while writing using the AES-128-CTR algorithm
Sourcefn aes256_ctr(self, key: Aes256Key, nonce: AesNonce) -> Aes256CtrBuilder<Self>
Available on crate feature aes_ctr only.
fn aes256_ctr(self, key: Aes256Key, nonce: AesNonce) -> Aes256CtrBuilder<Self>
aes_ctr only.Transformation that decrypts while reading and encrypts while writing using the AES-256-CTR algorithm
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.