pub trait RwBuilderExt: RwBuilder {
Show 21 methods
// Provided methods
fn buffered(self) -> BufferedBuilder<Self> { ... }
fn string(self) -> Builder<Self> { ... }
fn wincode(self) -> WincodeBuilder<Self> { ... }
fn chacha20(
self,
key: ChaCha20Key,
nonce: ChaCha20Nonce,
) -> ChaCha20Builder<Self> { ... }
fn salsa20(
self,
key: Salsa20Key,
nonce: Salsa20Nonce,
) -> Salsa20Builder<Self> { ... }
fn crc(self) -> CrcBuilder<Self> { ... }
fn deflate(
self,
compression: Compression,
) -> CompressionBuilder<Self, Deflate> { ... }
fn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz> { ... }
fn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib> { ... }
fn zstd(self, level: i32) -> ZstdBuilder<Self> { ... }
fn bzip2(self, compression: BzCompression) -> BzBuilder<Self> { ... }
fn lz4_flex(self) -> Lz4Builder<Self> { ... }
fn hash<D: Digest>(self) -> DigestBuilder<Self, D> { ... }
fn sha256(self) -> Sha256Builder<Self> { ... }
fn sha512(self) -> Sha512Builder<Self> { ... }
fn sha3_256(self) -> Sha3_256Builder<Self> { ... }
fn sha3_512(self) -> Sha3_512Builder<Self> { ... }
fn crc32fast(self) -> Crc32FastBuilder<Self> { ... }
fn rmp_serde(self) -> Builder<Self> { ... }
fn aes128_ctr(
self,
key: Aes128Key,
nonce: AesNonce,
) -> Aes128CtrBuilder<Self> { ... }
fn aes256_ctr(
self,
key: Aes256Key,
nonce: AesNonce,
) -> Aes256CtrBuilder<Self> { ... }
}Expand description
Extension trait providing combinator methods for RwBuilder instances
Provided Methods
Sourcefn buffered(self) -> BufferedBuilder<Self>
fn buffered(self) -> BufferedBuilder<Self>
Buffers the underlying readers and writers by wrapping them in a
BufReader or BufWriter
Sourcefn string(self) -> Builder<Self>
fn string(self) -> Builder<Self>
Sink that provides a bridge between String instances and underlying
readers and writers.
Sourcefn wincode(self) -> WincodeBuilder<Self>
fn wincode(self) -> WincodeBuilder<Self>
Sink that provides a bridge between serde and the underlying readers and writer by transforming from and to wincode.
Sourcefn chacha20(
self,
key: ChaCha20Key,
nonce: ChaCha20Nonce,
) -> ChaCha20Builder<Self>
fn chacha20( self, key: ChaCha20Key, nonce: ChaCha20Nonce, ) -> ChaCha20Builder<Self>
Transformation that decrypts while reading and encrypts while writing using the chacha20 cipher
Sourcefn salsa20(self, key: Salsa20Key, nonce: Salsa20Nonce) -> Salsa20Builder<Self>
fn salsa20(self, key: Salsa20Key, nonce: Salsa20Nonce) -> Salsa20Builder<Self>
Transformation that decrypts while reading and encrypts while writing using the salsa20 cipher
Sourcefn crc(self) -> CrcBuilder<Self>
fn crc(self) -> CrcBuilder<Self>
Non-commutative transformation that hashes using the CRC algorithm
Sourcefn deflate(self, compression: Compression) -> CompressionBuilder<Self, Deflate>
fn deflate(self, compression: Compression) -> CompressionBuilder<Self, Deflate>
Transformation that decompresses while reading and compresses while writing using the Deflate algorithm
Sourcefn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz>
fn gz(self, compression: Compression) -> CompressionBuilder<Self, Gz>
Transformation that decompresses while reading and compresses while writing using the Gz algorithm
Sourcefn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib>
fn zlib(self, compression: Compression) -> CompressionBuilder<Self, Zlib>
Transformation that decompresses while reading and compresses while writing using the Zlib algorithm
Sourcefn zstd(self, level: i32) -> ZstdBuilder<Self>
fn zstd(self, level: i32) -> ZstdBuilder<Self>
Transformation that decompresses while reading and compresses while writing using the Zstd algorithm
Sourcefn bzip2(self, compression: BzCompression) -> BzBuilder<Self>
fn bzip2(self, compression: BzCompression) -> BzBuilder<Self>
Transformation that decompresses while reading and compresses while writing using the bzip2 algorithm
Sourcefn lz4_flex(self) -> Lz4Builder<Self>
fn lz4_flex(self) -> Lz4Builder<Self>
Transformation that decompresses while reading and compresses while
writing using the lz4_flex algorithm
Sourcefn hash<D: Digest>(self) -> DigestBuilder<Self, D>
fn hash<D: Digest>(self) -> DigestBuilder<Self, D>
Computes a hash or checksum using the digest crate’s Digest trait while reading and writing.
Sourcefn sha256(self) -> Sha256Builder<Self>
fn sha256(self) -> Sha256Builder<Self>
Computes a SHA256 hash while reading and writing.
Sourcefn sha512(self) -> Sha512Builder<Self>
fn sha512(self) -> Sha512Builder<Self>
Computes a SHA512 hash while reading and writing.
Sourcefn sha3_256(self) -> Sha3_256Builder<Self>
fn sha3_256(self) -> Sha3_256Builder<Self>
Computes a SHA3-256 hash while reading and writing.
Sourcefn sha3_512(self) -> Sha3_512Builder<Self>
fn sha3_512(self) -> Sha3_512Builder<Self>
Computes a SHA3-512 hash while reading and writing.
Sourcefn crc32fast(self) -> Crc32FastBuilder<Self>
fn crc32fast(self) -> Crc32FastBuilder<Self>
Computes a CRC32 checksum using the crc32fast crate while reading and writing.
Sourcefn rmp_serde(self) -> Builder<Self>
fn rmp_serde(self) -> Builder<Self>
Sink that loads and saves values using rmp-serde (MessagePack).
Sourcefn aes128_ctr(self, key: Aes128Key, nonce: AesNonce) -> Aes128CtrBuilder<Self>
fn aes128_ctr(self, key: Aes128Key, nonce: AesNonce) -> Aes128CtrBuilder<Self>
Transformation that decrypts while reading and encrypts while writing using the AES-128-CTR algorithm
Sourcefn aes256_ctr(self, key: Aes256Key, nonce: AesNonce) -> Aes256CtrBuilder<Self>
fn aes256_ctr(self, key: Aes256Key, nonce: AesNonce) -> Aes256CtrBuilder<Self>
Transformation that decrypts while reading and encrypts while writing using the AES-256-CTR algorithm
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.